==> cl_appbase-0.0.6.tar.gz: lib/src/api/api_base.dart <==
import 'api_request_method.dart';
import 'api_resource.dart';
import 'package:cl_datahub_common/common.dart';

import 'api.dart';
import 'api_response.dart';

class ApiBase {
  final String baseUrl;
  final List<ApiResource> _resources = [];

  ApiBase(this.baseUrl);

  void bindResource(ApiResource resource) {
    if (_resources.contains(resource)) {
      throw ApiException('Cannot bind: Resource already bound to this api.');
    }

    if (resource.api != this) {
      throw ApiError('Cannot bind: Resource belongs to different api.');
    }

    _resources.add(resource);
  }

  Map<String, String> getRequestHeaders() {
    //TODO auth token and stuff
    return {};
  }

  Future<ApiResponse<TData>> getObject<TData>(String postfix,
      {Map<String, dynamic>? urlParams,
      Map<String, String>? query,
      DTOFactory? factory}) async {
    return await request<TData, TData>(
        baseUrl, postfix, urlParams, ApiRequestMethod.GET,
        headers: getRequestHeaders(), factory: factory, query: query);
  }

  Future<ApiResponse<List<TData>>> getList<TData>(String postfix,
      {Map<String, dynamic>? urlParams,
      Map<String, String>? query,
      DTOFactory? factory}) async {
    return await request<TData, List<TData>>(
        baseUrl, postfix, urlParams, ApiRequestMethod.GET,
        headers: getRequestHeaders(), factory: factory, query: query);
  }

  Future<ApiResponse<TData>> postObject<TData>(String postfix, TData object,
      {Map<String, dynamic>? urlParams,
      Map<String, String>? query,
      DTOFactory? factory}) async {
    return await request<TData, TData>(
        baseUrl, postfix, urlParams, ApiRequestMethod.POST,
        headers: getRequestHeaders(),
        factory: factory,
        body: object,
        query: query);
  }

  Future<ApiResponse<TData>> patchObject<TData>(String postfix, TData object,
      {Map<String, dynamic>? urlParams,
      Map<String, String>? query,
      DTOFactory? factory}) async {
    return await request<TData, TData>(
        baseUrl, postfix, urlParams, ApiRequestMethod.PATCH,
        headers: getRequestHeaders(),
        factory: factory,
        body: object,
        query: query);
  }

  Future<ApiResponse<void>> delete(String postfix,
      {Map<String, dynamic>? urlParams, Map<String, String>? query}) async {
    return await request<void, void>(
        baseUrl, postfix, urlParams, ApiRequestMethod.DELETE,
        headers: getRequestHeaders(), query: query);
  }
}

==> cl_appbase-0.0.20.tar.gz: lib/src/api/api_base.dart <==
import 'api_request_method.dart';
import 'api_resource.dart';
import 'package:cl_datahub_common/common.dart';

import 'api.dart';
import 'api_response.dart';

class ApiBase {
  final String baseUrl;
  final List<ApiResource> _resources = [];

  ApiBase(this.baseUrl);

  void bindResource(ApiResource resource) {
    if (_resources.contains(resource)) {
      throw ApiException('Cannot bind: Resource already bound to this api.');
    }

    if (resource.api != this) {
      throw ApiError('Cannot bind: Resource belongs to different api.');
    }

    _resources.add(resource);
  }

  Map<String, String> getRequestHeaders() {
    //TODO auth token and stuff
    return {};
  }

  Future<ApiResponse<TData>> getObject<TData>(String suffix,
      {Map<String, dynamic>? urlParams,
      Map<String, String>? query,
      DTOFactory? factory}) async {
    return await request<TData, TData>(
        baseUrl, suffix, urlParams, ApiRequestMethod.GET,
        headers: getRequestHeaders(), factory: factory, query: query);
  }

  Future<ApiResponse<List<TData>>> getList<TData>(String suffix,
      {Map<String, dynamic>? urlParams,
      Map<String, String>? query,
      DTOFactory? factory}) async {
    return await request<TData, List<TData>>(
        baseUrl, suffix, urlParams, ApiRequestMethod.GET,
        headers: getRequestHeaders(), factory: factory, query: query);
  }

  Future<ApiResponse<TData>> postObject<TData>(String suffix, dynamic object,
      {Map<String, dynamic>? urlParams,
      Map<String, String>? query,
      DTOFactory? factory}) async {
    return await request<TData, TData>(
        baseUrl, suffix, urlParams, ApiRequestMethod.POST,
        headers: getRequestHeaders(),
        factory: factory,
        body: object,
        query: query);
  }

  Future<ApiResponse<TData>> patchObject<TData>(String suffix, TData object,
      {Map<String, dynamic>? urlParams,
      Map<String, String>? query,
      DTOFactory? factory}) async {
    return await request<TData, TData>(
        baseUrl, suffix, urlParams, ApiRequestMethod.PATCH,
        headers: getRequestHeaders(),
        factory: factory,
        body: object,
        query: query);
  }

  Future<ApiResponse<void>> delete(String suffix,
      {Map<String, dynamic>? urlParams, Map<String, String>? query}) async {
    return await request<void, void>(
        baseUrl, suffix, urlParams, ApiRequestMethod.DELETE,
        headers: getRequestHeaders(), query: query);
  }
}
